// src/client.tsx
import { kebabCase } from "change-case";
import { render as renderHono } from "hono/jsx/dom";
import { Fragment, jsx, jsxs } from "hono/jsx/jsx-runtime";
function render(Component, options, props) {
  const name = kebabCase(Component.name);
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx("div", { id: `${name}-data`, "data-props": JSON.stringify(props) }),
    /* @__PURE__ */ jsx("script", { type: "module", defer: true, src: `${options.path}/${name}.js` })
  ] });
}
function mount(Component) {
  if (typeof document !== "undefined") {
    const name = kebabCase(Component.name);
    const dataElement = document.getElementById(`${name}-data`);
    if (!dataElement) {
      throw new Error(
        `unable to mount client component ${name}, data element not found. make sure you have a <div id="${name}-data"></div> in your html`
      );
    }
    const dataJson = dataElement.dataset.props;
    const data = JSON.parse(dataJson ?? "{}");
    console.info(`found data for client component ${name} in DOM`, data);
    const targetElement = document.getElementById(name);
    if (!targetElement) {
      throw new Error(
        `unable to render client component ${name}, target element not found. make sure you have a <div id="${name}"></div> in your html`
      );
    }
    renderHono(/* @__PURE__ */ jsx(Component, { ...data }), targetElement);
  }
}
export {
  mount,
  render
};
//# sourceMappingURL=client.js.map